==> zither-1.1.11.tar.gz: zither_prj/apollon/monitor_up.php <==
<?php

require("./total.inc");

session_start();
require("./ninsyou.inc");
if(0 > ninsyou_check(5)){
   exit;
   }

require("./socket.inc");
require("./list_file_upload.inc");


echo "<!DOCTYP:pserver:cvs@dhcvs.ms-n.com:/usr/home/cvsE HTML PUBLIC '-//W3C//DTD HTML 4.01 Transitional//EN'>";
echo "<HTML>";
echo "<HEAD>";
echo "<META name='GENERATOR' content='AmBuilder'>";
echo "<META http-equiv='Content-Type' content='text/html; charset=euc-jp'>";
	echo "<title>zither monitorring save info</title>";

echo "<SCRIPT LANGUAGE='JavaScript'>";
echo "<!--

function WinCls(){
        window.close()
                       }
//   window.onload=WinCls();
//-->";
echo "</SCRIPT>";

echo "</head>";
echo "<body alink='#ff0000' bgcolor='#ffffff' link='#0000ff' text='#000000' vlink='#000080'>";

echo "<pre>";
/* date */

$ncol1 = "bgcolor=#f0f0d2";
$ncol2 = "bgcolor=#d2f0f0";

$COME = $_GET["COME"];
$CNAME = $_GET["CNAME"];
$MONITOR = $_GET["MONITOR"];
$SIGN = $_GET["SIGN"];
$PROTO = $_GET["PROTO"];
$COM = $_GET["COM"];
$CIP = $_GET["CIP"];
$PORT = $_GET["PORT"];
$WTIME = $_GET["WTIME"];
$PINFO = $_GET["PINFO"];
$PRINO = $_GET["PRINO"];
$FREE1 = $_GET["FREE1"];
$FREE2 = $_GET["FREE2"];
$FREE3 = $_GET["FREE3"];
$FREE4 = $_GET["FREE4"];
$UNO = $_GET["UNO"];
$GEN = $_GET["GEN"];

$MAX = $_GET["MAX"];

$STATUS = $_GET["STATUS"];

print($font_size);
print($version_name);
print(date("Y m d g i s A"));
print("\n");



// ­Ƥ뤫γǧ

if(0 >= strlen($CNAME)){
   print("NOT CNAME ERR \n");
   }

if(0 >= strlen($FREE4)){
   print("NOT FREE4 ERR \n");
   }

if(0 >= strlen($UNO)){
   print("NOT UNO ERR \n");
   }

if(0 >= strlen($GEN)){
   print("NOT GEN ERR \n");
   }




//  ֥åºݤˤ뤫γǧ ƻ륯饤̾򵭲ޤ
$CNAME_NEW = cname_return($FREE4);
if(0 >= strlen($CNAME_NEW)){
   echo "not cname return!<br>";
   exit;
   }




// DB³
$conn = Pg_connect("hostaddr='$pg_connect_ip' port='5432' dbname='zither' connect_timeout='8'");
if(!$conn){
   echo "not connection!<br>";
   exit;
   }

if(0 < $MAX){
   $count = 0;
   $result=pg_query($conn,"select cname from monitor where free4='$FREE4';");
   if(!$result){
      print("canem select , bud query\n");
      exit;
      }
   $maxnum = pg_num_rows($result);
   if($maxnum >= $MAX){
      print("MAX $MAX \n");
      exit;
      }

   pg_free_result($result);
   }




// ѹΥ֥å̾ȥ饤̾򵭲ޤ
$result = pg_query($conn, "select * from monitor where uno='$UNO'");
if(!$result){
   print("bud query set\n");
   exit;
   }
$num = pg_num_rows($result);
if($num > 0){
   $FREE4_OLD = rtrim(pg_fetch_Result($result, $s, free4));
   $CNAME_OLD = rtrim(pg_fetch_Result($result, $s, cname));
   }
else{
   print("not data?\n");
   exit;
   }
pg_free_result($result);



if(0 < strlen($GEN)){

   // UPDATE ʤΤǥåץǡȤޤ
   if($STATUS == "UPDATE"){
      $result = pg_query($conn, "update monitor set
       come='$COME',
       cname='$CNAME_NEW',
       monitor='$MONITOR',
       sign=$SIGN,
       proto='$PROTO',
       com='$COM',
       cip='$CIP',
       port='$PORT',
       wtime=$WTIME,
       pinfo='$PINFO',
       prino=$PRINO,
       free1='$FREE1',
       free2='$FREE2',
       free3='$FREE3',
       free4='$FREE4'
       where uno=$UNO");

      if(!$result){
         print("bud query set\n");
         exit;
         }
      pg_free_result($result);
      print("ѹDBȿǤޤ\n");
      }

  // UPDATEǤϤʤΤǡɲäޤ
   else{
      $result = pg_query($conn, "insert into monitor values (
       '$COME',
       '$CNAME_NEW',
       '$MONITOR',
       $SIGN,
       '$PROTO',
       '$COM',
       '$CIP',
       '$PORT',
       $WTIME,
       '$PINFO',
       $PRINO,
       '$FREE1',
       '$FREE2',
       '$FREE3',
       '$FREE4')
       ");
      if(!$result){
         print("bud query set\n");
         exit;
         }
      }

   // ƻ륯饤ȤΥեѹ
   print("ƻ֥åѹƤޤ\n");
   // --- list file upload --- //
   if(0 != strcmp($CNAME_NEW, $CNAME_OLD)){
      list_file_upload($CNAME_NEW, $GEN);
      list_file_upload($CNAME_OLD, $GEN);
      }
   else{
      list_file_upload($CNAME_NEW, $GEN);
      }
   }


pg_free_result($result);
pg_Close($conn);

?>

</pre>
</body>
</html>

==> zither-1.1.15.tar.gz: zither_prj/apollon/monitor_up.php <==
<?php

require("./total.inc");

session_start();
require("./ninsyou.inc");
if(0 > ninsyou_check(5)){
   exit;
   }



echo "<!DOCTYP:pserver:cvs@dhcvs.ms-n.com:/usr/home/cvsE HTML PUBLIC '-//W3C//DTD HTML 4.01 Transitional//EN'>";
echo "<HTML>";
echo "<HEAD>";
echo "<META name='GENERATOR' content='AmBuilder'>";
echo "<META http-equiv='Content-Type' content='text/html; charset=euc-jp'>";
	echo "<title>zither monitorring save info</title>";

echo "<SCRIPT LANGUAGE='JavaScript'>";
echo "<!--

function WinCls(){
        window.close()
                       }
//   window.onload=WinCls();
//-->";
echo "</SCRIPT>";

echo "</head>";
echo "<body alink='#ff0000' bgcolor='#ffffff' link='#0000ff' text='#000000' vlink='#000080'>";

echo "<pre>";
/* date */

$ncol1 = "bgcolor=#f0f0d2";
$ncol2 = "bgcolor=#d2f0f0";

$COME = enco($_GET["COME"]);
$CNAME = enco($_GET["CNAME"]);
$MONITOR = enco($_GET["MONITOR"]);
$SIGN = enco($_GET["SIGN"]);
$PROTO = enco($_GET["PROTO"]);
$COM = enco($_GET["COM"]);
$CIP = enco($_GET["CIP"]);
$PORT = enco($_GET["PORT"]);
$WTIME = enco($_GET["WTIME"]);
$PINFO = enco($_GET["PINFO"]);
$PRINO = enco($_GET["PRINO"]);
$FREE1 = enco($_GET["FREE1"]);
$FREE2 = enco($_GET["FREE2"]);
$FREE3 = enco($_GET["FREE3"]);
$FREE4 = enco($_GET["FREE4"]);
$UNO = enco($_GET["UNO"]);
$GEN = enco($_GET["GEN"]);

$MAX = enco($_GET["MAX"]);

$STATUS = enco($_GET["STATUS"]);

print($font_size);
print($version_name);
print(date("Y m d g i s A"));
print("\n");



// ­Ƥ뤫γǧ

if(0 >= strlen($CNAME)){
   print("NOT CNAME ERR \n");
   }

if(0 >= strlen($FREE4)){
   print("NOT FREE4 ERR \n");
   }

if(0 >= strlen($UNO)){
   print("NOT UNO ERR \n");
   }

if(0 >= strlen($GEN)){
   print("NOT GEN ERR \n");
   }




//  ֥åºݤˤ뤫γǧ ƻ륯饤̾򵭲ޤ
$CNAME_NEW = cname_return($FREE4);
if(0 >= strlen($CNAME_NEW)){
   echo "not cname return!<br>";
   exit;
   }




// DB³
$conn = Pg_connect("hostaddr='$pg_connect_ip' port='5432' dbname='zither' connect_timeout='8'");
if(!$conn){
   echo "not connection!<br>";
   exit;
   }

if(0 < $MAX){
   $count = 0;
   $result=pg_query($conn,"select cname from monitor where free4='$FREE4';");
   if(!$result){
      print("canem select , bud query\n");
      exit;
      }
   $maxnum = pg_num_rows($result);
   if($maxnum >= $MAX){
      print("MAX $MAX \n");
      exit;
      }

   pg_free_result($result);
   }




// ѹΥ֥å̾ȥ饤̾򵭲ޤ
$result = pg_query($conn, "select * from monitor where uno='$UNO'");
if(!$result){
   print("bud query set\n");
   exit;
   }
$num = pg_num_rows($result);
if($num > 0){
   $FREE4_OLD = enco_rtrim(pg_fetch_Result($result, $s, free4));
   $CNAME_OLD = enco_rtrim(pg_fetch_Result($result, $s, cname));
   }
else{
   print("not data?\n");
   exit;
   }
pg_free_result($result);



if(0 < strlen($GEN)){

   // UPDATE ʤΤǥåץǡȤޤ
   if($STATUS == "UPDATE"){
      $result = pg_query($conn, "update monitor set
       come='$COME',
       cname='$CNAME_NEW',
       monitor='$MONITOR',
       sign=$SIGN,
       proto='$PROTO',
       com='$COM',
       cip='$CIP',
       port='$PORT',
       wtime=$WTIME,
       pinfo='$PINFO',
       prino=$PRINO,
       free1='$FREE1',
       free2='$FREE2',
       free3='$FREE3',
       free4='$FREE4'
       where uno=$UNO");

      if(!$result){
         print("bud query set\n");
         exit;
         }
      pg_free_result($result);
      print("ѹDBȿǤޤ\n");
      }

  // UPDATEǤϤʤΤǡɲäޤ
   else{
      $result = pg_query($conn, "insert into monitor values (
       '$COME',
       '$CNAME_NEW',
       '$MONITOR',
       $SIGN,
       '$PROTO',
       '$COM',
       '$CIP',
       '$PORT',
       $WTIME,
       '$PINFO',
       $PRINO,
       '$FREE1',
       '$FREE2',
       '$FREE3',
       '$FREE4')
       ");
      if(!$result){
         print("bud query set\n");
         exit;
         }
      }

   // ƻ륯饤ȤΥեѹ
   print("ƻ֥åѹƤޤ\n");
   // --- list file upload --- //
   if(0 != strcmp($CNAME_NEW, $CNAME_OLD)){
      list_file_upload($CNAME_NEW, $GEN);
      list_file_upload($CNAME_OLD, $GEN);
      }
   else{
      list_file_upload($CNAME_NEW, $GEN);
      }
   }


pg_free_result($result);
pg_Close($conn);

?>

</pre>
</body>
</html>
